@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21682 $
- * $Author: rjongbloed $
- * $Date: 2008-12-02 17:47:17 -0600 (Tue, 02 Dec 2008) $
+ * $Revision: 25456 $
+ * $Author: ededu $
+ * $Date: 2011-03-30 14:15:51 -0500 (Wed, 30 Mar 2011) $
  */
 
 #define P_DISABLE_FACTORY_INSTANCES
@@ -56,6 +56,7 @@ static BOOL CALLBACK EnumWindowsProc(HWND hWnd, LPARAM thisProcess)
   if (wndProcess != (DWORD)thisProcess)
     return PTrue;
 
+  PTRACE(4, "PTLib\tAwaiting key press on exit.");
   cerr << "\nPress a key to continue . . .";
   cerr.flush();
 
@@ -271,8 +272,8 @@ void PAssertFunc(const char * msg)
 
   if (PProcess::Current().IsServiceProcess()) {
 #ifndef _WIN32_WCE
-	PSystemLog::Output(PSystemLog::Fatal, sstr.c_str());
-#if defined(_MSC_VER) && defined(_DEBUG)
+    PSYSTEMLOG(Fatal, sstr);
+#if defined(_MSC_VER) && defined(_DEBUG) && !defined(_WIN64)
     if (PServiceProcess::Current().debugMode)
       __asm int 3;
 #endif
@@ -280,6 +281,8 @@ void PAssertFunc(const char * msg)
     return;
   }
 
+  PTRACE(0, sstr);
+
 #if defined(_WIN32)
   static HANDLE mutex = CreateSemaphore(NULL, 1, 1, NULL);
   WaitForSingleObject(mutex, INFINITE);
@@ -319,7 +322,7 @@ void PAssertFunc(const char * msg)
 #if defined(_WIN32)
         ReleaseSemaphore(mutex, 1, NULL);
 #endif
-#if defined(_MSC_VER) && !defined(_WIN32_WCE)
+#if defined(_MSC_VER) && !defined(_WIN32_WCE) && !defined(_WIN64)
         __asm int 3;
 #endif
 
